@@ -43,12 +43,6 @@ class UpdateFileRequest(RpcRequest):
 	def set_DependentNodeIdList(self,DependentNodeIdList):
 		self.add_body_params('DependentNodeIdList', DependentNodeIdList)
 
-	def get_AutoParse(self):
-		return self.get_body_params().get('AutoParse')
-
-	def set_AutoParse(self,AutoParse):
-		self.add_body_params('AutoParse', AutoParse)
-
 	def get_Content(self):
 		return self.get_body_params().get('Content')
 
@@ -173,4 +167,16 @@ class UpdateFileRequest(RpcRequest):
 		return self.get_body_params().get('FileDescription')
 
 	def set_FileDescription(self,FileDescription):
-		self.add_body_params('FileDescription', FileDescription)
\ No newline at end of file
+		self.add_body_params('FileDescription', FileDescription)
+
+	def get_AutoParsing(self):
+		return self.get_body_params().get('AutoParsing')
+
+	def set_AutoParsing(self,AutoParsing):
+		self.add_body_params('AutoParsing', AutoParsing)
+
+	def get_SchedulerType(self):
+		return self.get_body_params().get('SchedulerType')
+
+	def set_SchedulerType(self,SchedulerType):
+		self.add_body_params('SchedulerType', SchedulerType)
\ No newline at end of file
